Module blaxel.core.client.models.volume_state
=============================================

Classes
-------

`VolumeState(attached_to: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Volume state - mutable runtime state
    
    Attributes:
        attached_to (Union[Unset, str]): Resource this volume is attached to (e.g. "sandbox:my-sandbox", "model:my-
            model")
    
    Method generated by attrs for class VolumeState.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `attached_to: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :